yx_state_transformers library

Custom task transformers for yx_state.

This package provides various concurrency strategies for handling tasks in state management operations.

Functions

concurrent<State extends Object?>() → FunctionHandler<State>
Process tasks concurrently without any restrictions.
droppable<State extends Object?>() → FunctionHandler<State>
Process only one task and ignore (drop) any new tasks until the current task is done.
restartable<State extends Object?>() → FunctionHandler<State>
Process only one task by cancelling any pending tasks and processing the new task immediately.
sequential<State extends Object?>() → FunctionHandler<State>
Process tasks one at a time by maintaining a queue of added tasks and processing the tasks sequentially.