droppable<State extends Object?> function

FunctionHandler<State> droppable<State extends Object?>()

Process only one task and ignore (drop) any new tasks until the current task is done.

Useful for preventing spamming of state updates during ongoing operations.

Implementation

FunctionHandler<State> droppable<State extends Object?>() =>
    StreamFunctionHandler<State>(
        handleTransformer: HandleTaskTransformers.droppable());