restartable<State extends Object?> function
FunctionHandler<State>
restartable<State extends Object?>()
Process only one task by cancelling any pending tasks and processing the new task immediately.
Useful for operations where only the latest request matters.
Implementation
FunctionHandler<State> restartable<State extends Object?>() =>
StreamFunctionHandler<State>(
handleTransformer: HandleTaskTransformers.restartable());